==> ssp-center-api-0.9.95-20211215.025623-16-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteActivitySlotBackendService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.boot.netflix.feign.hystrix.FeignHystrixProperty;
import cn.com.duiba.boot.netflix.feign.hystrix.conf.HystrixPropertiesManager;
import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;
import java.util.Map;

/**
 * @author xuyenan
 * @createTime 2016/12/26
 */
@AdvancedFeignClient
public interface RemoteActivitySlotBackendService {

    /**
     * 添加广告位
     * 
     * @param slotIds 广告位ID列表
     * @return Boolean
     */
    DubboResult<Boolean> addSlots(List<Long> slotIds);

    /**
     * 删除广告位
     * 
     * @param slotId 广告位ID
     * @return Boolean
     */
    DubboResult<Boolean> deleteSlot(Long slotId);

    /**
     * 查询广告位列表
     * 
     * @param req 查询条件
     * @return 广告位列表
     */
    @FeignHystrixProperty(name= HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value="6000")
    DubboResult<PageResultDto<RspActivitySlotDto>> getList(ReqActivitySlotDto req);

    /**
     * 添加广告位时的查询接口
     * 
     * @param ids
     * @return 规格列表
     */
    DubboResult<List<SlotDto>> getSlotByIds(List<Long> ids);

    /**
     * 添加广告位时的查询接口(带权限)
     *
     * @param ids
     * @return 规格列表
     */
    DubboResult<List<SlotDto>> getSlotByIdsV2(List<Long> ids, List<Long> managerAppIds);

    /**
     * 查询定制广告位
     * 
     * @param slotId id
     * @return 广告位
     */
    DubboResult<RspActivitySlotDto> getById(Long slotId);

    /**
     * 更新定制广告定向模式
     * 
     * @param slotId 广告ID
     * @param directMode 定向模式
     * @return Boolean
     */
    DubboResult<Boolean> updateDirectMode(Long slotId, Integer directMode);

    /**
     * copySlot:(拷贝广告位). <br/>
     *
     * @param req
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> copySlot(ReqCopySlot req, Map<Integer, String> actTypeMap);


    /**
     * copySlot:(拷贝广告位). <br/>
     *
     * @param req
     * @return
     * @since JDK 1.6
     */
    Boolean copySlotDistinguishDeep(ReqCopySlot req, Map<Integer, String> actTypeMap, Map<String, Object> deepMap);

    Result<Boolean> copySlotDistinguishDeepRegion(ReqCopySlot req, Map<Integer, String> actTypeMap, Map<String, Object> deepMap, Long regionId) throws BizException;

    Result<Boolean> isDirectMediaOrSlot(ReqCopySlot req, Long activityId, Integer source,
                                        Map<Integer, String> actTypeMap);
}

==> ssp-center-api-1.1.08-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteActivitySlotBackendService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.boot.netflix.feign.hystrix.FeignHystrixProperty;
import cn.com.duiba.boot.netflix.feign.hystrix.conf.HystrixPropertiesManager;
import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;
import java.util.Map;

/**
 * @author xuyenan
 * @createTime 2016/12/26
 */
@AdvancedFeignClient
public interface RemoteActivitySlotBackendService {

    /**
     * 添加广告位
     * 
     * @param slotIds 广告位ID列表
     * @return Boolean
     */
    DubboResult<Boolean> addSlots(List<Long> slotIds);

    /**
     * 删除广告位
     * 
     * @param slotId 广告位ID
     * @return Boolean
     */
    DubboResult<Boolean> deleteSlot(Long slotId);

    /**
     * 查询广告位列表
     * 
     * @param req 查询条件
     * @return 广告位列表
     */
    @FeignHystrixProperty(name= HystrixPropertiesManager.EXECUTION_ISOLATION_THREAD_TIMEOUT_IN_MILLISECONDS, value="6000")
    DubboResult<PageResultDto<RspActivitySlotDto>> getList(ReqActivitySlotDto req);

    /**
     * 添加广告位时的查询接口
     * 
     * @param ids
     * @return 规格列表
     */
    DubboResult<List<SlotDto>> getSlotByIds(List<Long> ids);

    /**
     * 添加广告位时的查询接口(带权限)
     *
     * @param ids
     * @return 规格列表
     */
    DubboResult<List<SlotDto>> getSlotByIdsV2(List<Long> ids, List<Long> managerAppIds);

    /**
     * 查询定制广告位
     * 
     * @param slotId id
     * @return 广告位
     */
    DubboResult<RspActivitySlotDto> getById(Long slotId);

    /**
     * 更新定制广告定向模式
     * 
     * @param slotId 广告ID
     * @param directMode 定向模式
     * @return Boolean
     */
    DubboResult<Boolean> updateDirectMode(Long slotId, Integer directMode);

    /**
     * copySlot:(拷贝广告位). <br/>
     *
     * @param req
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> copySlot(ReqCopySlot req, Map<Integer, String> actTypeMap);


    /**
     * copySlot:(拷贝广告位). <br/>
     *
     * @param req
     * @return
     * @since JDK 1.6
     */
    Boolean copySlotDistinguishDeep(ReqCopySlot req, Map<Integer, String> actTypeMap, Map<String, Object> deepMap);

    Result<Boolean> copySlotDistinguishDeepRegion(ReqCopySlot req, Map<Integer, String> actTypeMap, Map<String, Object> deepMap, Long regionId) throws BizException;

    Result<Boolean> isDirectMediaOrSlot(ReqCopySlot req, Long regionId,
                                        Map<Integer, String> actTypeMap);
}
